@@ -33,9 +33,9 @@ pub fn estimate_hours(
         for next in commits {
             let change_in_minutes = (next.time.seconds.saturating_sub(cur.time.seconds)) as f32 / MINUTES_PER_HOUR;
             if change_in_minutes < MAX_COMMIT_DIFFERENCE_IN_MINUTES {
-                hours += change_in_minutes / MINUTES_PER_HOUR
+                hours += change_in_minutes / MINUTES_PER_HOUR;
             } else {
-                hours += FIRST_COMMIT_ADDITION_IN_MINUTES / MINUTES_PER_HOUR
+                hours += FIRST_COMMIT_ADDITION_IN_MINUTES / MINUTES_PER_HOUR;
             }
             cur = next;
         }
@@ -105,7 +105,7 @@ pub fn spawn_tree_delta_threads<'scope>(
                     for chunk in rx {
                         for (commit_idx, parent_commit, commit) in chunk {
                             if let Some(cache) = cache.as_mut() {
-                                cache.clear_resource_cache();
+                                cache.clear_resource_cache_keep_allocation();
                             }
                             commits.fetch_add(1, Ordering::Relaxed);
                             if gix::interrupt::is_triggered() {
@@ -125,22 +125,23 @@ pub fn spawn_tree_delta_threads<'scope>(
                                 None => continue,
                             };
                             from.changes()?
-                                .track_filename()
-                                .track_rewrites(None)
+                                .options(|opts| {
+                                    opts.track_filename().track_rewrites(None);
+                                })
                                 .for_each_to_obtain_tree(&to, |change| {
-                                    use gix::object::tree::diff::change::Event::*;
+                                    use gix::object::tree::diff::Change::*;
                                     changes.fetch_add(1, Ordering::Relaxed);
-                                    match change.event {
+                                    match change {
                                         Rewrite { .. } => {
                                             unreachable!("we turned that off")
                                         }
-                                        Addition { entry_mode, id } => {
+                                        Addition { entry_mode, id, .. } => {
                                             if entry_mode.is_no_tree() {
                                                 files.added += 1;
                                                 add_lines(line_stats, &lines_count, &mut lines, id);
                                             }
                                         }
-                                        Deletion { entry_mode, id } => {
+                                        Deletion { entry_mode, id, .. } => {
                                             if entry_mode.is_no_tree() {
                                                 files.removed += 1;
                                                 remove_lines(line_stats, &lines_count, &mut lines, id);
@@ -151,6 +152,7 @@ pub fn spawn_tree_delta_threads<'scope>(
                                             previous_entry_mode,
                                             id,
                                             previous_id,
+                                            ..
                                         } => match (previous_entry_mode.is_blob(), entry_mode.is_blob()) {
                                             (false, false) => {}
                                             (false, true) => {
