@@ -19,6 +19,8 @@ pub enum PathsOrPatterns {
 
 #[cfg(feature = "archive")]
 pub mod archive;
+pub mod cat;
+pub use cat::function::cat;
 pub mod commit;
 pub mod config;
 mod credential;
@@ -26,6 +28,7 @@ pub use credential::function as credential;
 pub mod attributes;
 #[cfg(feature = "clean")]
 pub mod clean;
+pub mod diff;
 pub mod dirty;
 #[cfg(feature = "clean")]
 pub use clean::function::clean;
@@ -44,6 +47,9 @@ mod fsck;
 pub use fsck::function as fsck;
 pub mod index;
 pub mod mailmap;
+mod merge_base;
+pub use merge_base::merge_base;
+pub mod merge;
 pub mod odb;
 pub mod remote;
 pub mod revision;
@@ -51,3 +57,4 @@ pub mod status;
 pub mod submodule;
 pub mod tree;
 pub mod verify;
+pub mod worktree;
