@@ -5,17 +5,14 @@ use crate::file::cow_str;
 #[test]
 fn single_value_is_identical_to_single_value_query() -> crate::Result {
     let config = File::try_from("[core]\na=b\nc=d")?;
-    assert_eq!(
-        vec![config.raw_value("core", None, "a")?],
-        config.raw_values("core", None, "a")?
-    );
+    assert_eq!(vec![config.raw_value("core.a")?], config.raw_values("core.a")?);
     Ok(())
 }
 
 #[test]
 fn multi_value_in_section() -> crate::Result {
     let config = File::try_from("[core]\na=b\na=c")?;
-    assert_eq!(config.raw_values("core", None, "a")?, vec![cow_str("b"), cow_str("c")]);
+    assert_eq!(config.raw_values("core.a")?, vec![cow_str("b"), cow_str("c")]);
     Ok(())
 }
 
@@ -23,7 +20,7 @@ fn multi_value_in_section() -> crate::Result {
 fn multi_value_across_sections() -> crate::Result {
     let config = File::try_from("[core]\na=b\na=c\n[core]a=d")?;
     assert_eq!(
-        config.raw_values("core", None, "a")?,
+        config.raw_values("core.a")?,
         vec![cow_str("b"), cow_str("c"), cow_str("d")]
     );
     Ok(())
@@ -33,7 +30,7 @@ fn multi_value_across_sections() -> crate::Result {
 fn section_not_found() -> crate::Result {
     let config = File::try_from("[core]\na=b\nc=d")?;
     assert!(matches!(
-        config.raw_values("foo", None, "a"),
+        config.raw_values("foo.a"),
         Err(lookup::existing::Error::SectionMissing)
     ));
     Ok(())
@@ -43,7 +40,7 @@ fn section_not_found() -> crate::Result {
 fn subsection_not_found() -> crate::Result {
     let config = File::try_from("[core]\na=b\nc=d")?;
     assert!(matches!(
-        config.raw_values("core", Some("a".into()), "a"),
+        config.raw_values("core.a.a"),
         Err(lookup::existing::Error::SubSectionMissing)
     ));
     Ok(())
@@ -53,7 +50,7 @@ fn subsection_not_found() -> crate::Result {
 fn key_not_found() -> crate::Result {
     let config = File::try_from("[core]\na=b\nc=d")?;
     assert!(matches!(
-        config.raw_values("core", None, "aaaaaa"),
+        config.raw_values("core.aaaaaa"),
         Err(lookup::existing::Error::KeyMissing)
     ));
     Ok(())
@@ -62,8 +59,8 @@ fn key_not_found() -> crate::Result {
 #[test]
 fn subsection_must_be_respected() -> crate::Result {
     let config = File::try_from("[core]a=b\n[core.a]a=c")?;
-    assert_eq!(config.raw_values("core", None, "a")?, vec![cow_str("b")]);
-    assert_eq!(config.raw_values("core", Some("a".into()), "a")?, vec![cow_str("c")]);
+    assert_eq!(config.raw_values("core.a")?, vec![cow_str("b")]);
+    assert_eq!(config.raw_values("core.a.a")?, vec![cow_str("c")]);
     Ok(())
 }
 
@@ -71,7 +68,7 @@ fn subsection_must_be_respected() -> crate::Result {
 fn non_relevant_subsection_is_ignored() -> crate::Result {
     let config = File::try_from("[core]\na=b\na=c\n[core]a=d\n[core]g=g")?;
     assert_eq!(
-        config.raw_values("core", None, "a")?,
+        config.raw_values("core.a")?,
         vec![cow_str("b"), cow_str("c"), cow_str("d")]
     );
     Ok(())
