@@ -4,12 +4,12 @@ fn file(input: &str) -> gix_config::File<'static> {
 
 fn assert_set_value(value: &str) {
     let mut file = file("[a]k=b\n[a]\nk=c\nk=d");
-    file.set_existing_raw_value("a", None, "k", value).unwrap();
-    assert_eq!(file.raw_value("a", None, "k").unwrap().as_ref(), value);
+    file.set_existing_raw_value_by("a", None, "k", value).unwrap();
+    assert_eq!(file.raw_value("a.k").unwrap().as_ref(), value);
 
     let file: gix_config::File = file.to_string().parse().unwrap();
     assert_eq!(
-        file.raw_value("a", None, "k").unwrap().as_ref(),
+        file.raw_value("a.k").unwrap().as_ref(),
         value,
         "{:?} didn't have expected value {:?}",
         file.to_string(),
@@ -54,7 +54,7 @@ fn comment_included() {
 fn non_existing_values_cannot_be_set() {
     let mut file = gix_config::File::default();
     assert!(
-        file.set_existing_raw_value("new", None, "key", "value").is_err(),
+        file.set_existing_raw_value_by("new", None, "key", "value").is_err(),
         "new values are not ever created"
     );
 }
