@@ -394,16 +394,16 @@ fn overlay_iter() -> crate::Result {
     assert_eq!(
         ref_names,
         vec![
-            (b"refs/heads/main".as_bstr().to_owned(), Peeled(c1)),
-            ("refs/heads/newer-as-loose".into(), Peeled(c2)),
+            (b"refs/heads/main".as_bstr().to_owned(), Object(c1)),
+            ("refs/heads/newer-as-loose".into(), Object(c2)),
             (
                 "refs/remotes/origin/HEAD".into(),
                 Symbolic("refs/remotes/origin/main".try_into()?),
             ),
-            ("refs/remotes/origin/main".into(), Peeled(c1)),
+            ("refs/remotes/origin/main".into(), Object(c1)),
             (
                 "refs/tags/tag-object".into(),
-                Peeled(hex_to_id("b3109a7e51fc593f85b145a76c70ddd1d133fafd")),
+                Object(hex_to_id("b3109a7e51fc593f85b145a76c70ddd1d133fafd")),
             )
         ]
     );
@@ -440,8 +440,8 @@ fn overlay_prefixed_iter() -> crate::Result {
     assert_eq!(
         ref_names,
         vec![
-            (b"refs/heads/main".as_bstr().to_owned(), Peeled(c1)),
-            ("refs/heads/newer-as-loose".into(), Peeled(c2)),
+            (b"refs/heads/main".as_bstr().to_owned(), Object(c1)),
+            ("refs/heads/newer-as-loose".into(), Object(c2)),
         ]
     );
     Ok(())
@@ -458,6 +458,6 @@ fn overlay_partial_prefix_iter() -> crate::Result {
         .map(|r| r.map(|r| (r.name.as_bstr().to_owned(), r.target)))
         .collect::<Result<Vec<_>, _>>()?;
     let c1 = hex_to_id("134385f6d781b7e97062102c6a483440bfda2a03");
-    assert_eq!(ref_names, vec![(b"refs/heads/main".as_bstr().to_owned(), Peeled(c1)),]);
+    assert_eq!(ref_names, vec![(b"refs/heads/main".as_bstr().to_owned(), Object(c1)),]);
     Ok(())
 }
