@@ -33,7 +33,7 @@ fn conflicting_creation_without_packed_refs() -> crate::Result {
         Ok(_) if !case_sensitive => panic!("should fail as 'a' and 'A' clash"),
         Err(err) if case_sensitive => panic!("should work as case sensitivity allows 'a' and 'A' to coexist: {err:?}"),
         Err(err) if !case_sensitive => {
-            assert_eq!(err.to_string(), "A lock could not be obtained for reference \"refs/A\"")
+            assert_eq!(err.to_string(), "A lock could not be obtained for reference \"refs/A\"");
         }
         _ => unreachable!("actually everything is covered"),
     }
@@ -127,7 +127,7 @@ fn conflicting_creation_into_packed_refs() -> crate::Result {
                     change: Change::Update {
                         log: LogChange::default(),
                         expected: PreviousValue::Any,
-                        new: Target::Peeled(gix_hash::Kind::Sha1.null()),
+                        new: Target::Object(gix_hash::Kind::Sha1.null()),
                     },
                     name: "refs/a".try_into().expect("valid"),
                     deref: false,
@@ -135,10 +135,10 @@ fn conflicting_creation_into_packed_refs() -> crate::Result {
                 RefEdit {
                     change: Change::Update {
                         log: LogChange::default(),
-                        expected: PreviousValue::MustExistAndMatch(Target::Peeled(hex_to_id(
+                        expected: PreviousValue::MustExistAndMatch(Target::Object(hex_to_id(
                             "e69de29bb2d1d6434b8b29ae775ad8c2e48c5391",
                         ))),
-                        new: Target::Peeled(gix_hash::Kind::Sha1.null()),
+                        new: Target::Object(gix_hash::Kind::Sha1.null()),
                     },
                     name: "refs/A".try_into().expect("valid"),
                     deref: false,
