@@ -36,4 +36,9 @@ git init all-untracked
 git init empty-core-excludes
 (cd empty-core-excludes
   echo $'[core]\n\texcludesFile = ' >> .git/config
+)
+
+git clone --bare . non-bare-without-worktree
+(cd non-bare-without-worktree
+  git config core.bare false
 )
\ No newline at end of file
