@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 set -eu -o pipefail
 
 function tick () {
@@ -116,6 +116,11 @@ git clone --shared base clone
   git remote add myself .
 )
 
+git clone --shared base head-ref
+(cd head-ref
+  git rev-parse @ > .git/refs/heads/HEAD
+)
+
 git clone --no-tags --shared base clone-no-tags
 (cd clone-no-tags
   git remote add --no-tags myself-no-tags .
