@@ -1,9 +1,7 @@
 #![deny(rust_2018_idioms, unsafe_code)]
 
-mod porcelain;
-
 fn main() -> anyhow::Result<()> {
-    porcelain::main()
+    gitoxide::porcelain::main()
 }
 
 #[cfg(not(feature = "pretty-cli"))]
