@@ -14,6 +14,7 @@ use gitoxide_core as core;
 use gitoxide_core::{pack::verify, repository::PathsOrPatterns};
 use gix::bstr::{io::BufReadExt, BString};
 
+use crate::plumbing::options::merge;
 use crate::plumbing::{
     options::{
         attributes, commit, commitgraph, config, credential, exclude, free, fsck, index, mailmap, odb, revision, tree,
@@ -54,11 +55,6 @@ pub mod async_util {
 
 pub fn main() -> Result<()> {
     let args: Args = Args::parse_from(gix::env::args_os());
-    #[allow(unsafe_code)]
-    unsafe {
-        // SAFETY: we don't manipulate the environment from any thread
-        time::util::local_offset::set_soundness(time::util::local_offset::Soundness::Unsound);
-    }
     let thread_limit = args.threads;
     let verbose = args.verbose;
     let format = args.format;
@@ -68,7 +64,7 @@ pub fn main() -> Result<()> {
     let mut trace = false;
     #[cfg(feature = "tracing")]
     {
-        trace = args.trace
+        trace = args.trace;
     }
     let object_hash = args.object_hash;
     let config = args.config;
@@ -110,8 +106,12 @@ pub fn main() -> Result<()> {
             };
             mapping.full.modify(to_match_settings);
             mapping.reduced.modify(to_match_settings);
-            let mut repo = gix::ThreadSafeRepository::discover_opts(repository, Default::default(), mapping)
-                .map(gix::Repository::from)?;
+            let mut repo = gix::ThreadSafeRepository::discover_with_environment_overrides_opts(
+                repository,
+                Default::default(),
+                mapping,
+            )
+            .map(gix::Repository::from)?;
             if !config.is_empty() {
                 repo.config_snapshot_mut()
                     .append_config(config.iter(), gix::config::Source::Cli)
@@ -146,6 +146,80 @@ pub fn main() -> Result<()> {
     }
 
     match cmd {
+        Subcommands::Merge(merge::Platform { cmd }) => match cmd {
+            merge::SubCommands::File {
+                resolve_with,
+                ours,
+                base,
+                theirs,
+            } => prepare_and_run(
+                "merge-file",
+                trace,
+                verbose,
+                progress,
+                progress_keep_open,
+                None,
+                move |_progress, out, _err| {
+                    core::repository::merge::file(
+                        repository(Mode::Lenient)?,
+                        out,
+                        format,
+                        resolve_with.map(|c| match c {
+                            merge::ResolveWith::Union => {
+                                gix::merge::blob::builtin_driver::text::Conflict::ResolveWithUnion
+                            }
+                            merge::ResolveWith::Ours => {
+                                gix::merge::blob::builtin_driver::text::Conflict::ResolveWithOurs
+                            }
+                            merge::ResolveWith::Theirs => {
+                                gix::merge::blob::builtin_driver::text::Conflict::ResolveWithTheirs
+                            }
+                        }),
+                        base,
+                        ours,
+                        theirs,
+                    )
+                },
+            ),
+        },
+        Subcommands::MergeBase(crate::plumbing::options::merge_base::Command { first, others }) => prepare_and_run(
+            "merge-base",
+            trace,
+            verbose,
+            progress,
+            progress_keep_open,
+            None,
+            move |_progress, out, _err| {
+                core::repository::merge_base(repository(Mode::Lenient)?, first, others, out, format)
+            },
+        ),
+        Subcommands::Diff(crate::plumbing::options::diff::Platform { cmd }) => match cmd {
+            crate::plumbing::options::diff::SubCommands::Tree {
+                old_treeish,
+                new_treeish,
+            } => prepare_and_run(
+                "diff-tree",
+                trace,
+                verbose,
+                progress,
+                progress_keep_open,
+                None,
+                move |_progress, out, _err| {
+                    core::repository::diff::tree(repository(Mode::Lenient)?, out, old_treeish, new_treeish)
+                },
+            ),
+        },
+        Subcommands::Worktree(crate::plumbing::options::worktree::Platform { cmd }) => match cmd {
+            crate::plumbing::options::worktree::SubCommands::List => prepare_and_run(
+                "worktree-list",
+                trace,
+                verbose,
+                progress,
+                progress_keep_open,
+                None,
+                move |_progress, out, _err| core::repository::worktree::list(repository(Mode::Lenient)?, out, format),
+            ),
+        },
         Subcommands::IsClean | Subcommands::IsChanged => {
             let mode = if matches!(cmd, Subcommands::IsClean) {
                 core::repository::dirty::Mode::IsClean
@@ -1063,6 +1137,15 @@ pub fn main() -> Result<()> {
                 },
             ),
         },
+        Subcommands::Cat { revspec } => prepare_and_run(
+            "cat",
+            trace,
+            verbose,
+            progress,
+            progress_keep_open,
+            None,
+            move |_progress, out, _err| core::repository::cat(repository(Mode::Lenient)?, &revspec, out),
+        ),
         Subcommands::Commit(cmd) => match cmd {
             commit::Subcommands::Verify { rev_spec } => prepare_and_run(
                 "commit-verify",
