@@ -83,7 +83,7 @@ pub enum Subcommands {
     Archive(archive::Platform),
     #[cfg(feature = "gitoxide-core-tools-clean")]
     Clean(clean::Command),
-    /// Subcommands for interacting with commit-graphs
+    /// Subcommands for interacting with commit-graph files
     #[clap(subcommand)]
     CommitGraph(commitgraph::Subcommands),
     /// Interact with the object database.
@@ -130,6 +130,11 @@ pub enum Subcommands {
     /// Interact with submodules.
     #[clap(alias = "submodules")]
     Submodule(submodule::Platform),
+    /// Show whatever object is at the given spec.
+    Cat {
+        /// The object to print to stdout.
+        revspec: String,
+    },
     IsClean,
     IsChanged,
     /// Show which git configuration values are used or planned.
@@ -138,6 +143,10 @@ pub enum Subcommands {
     Config(config::Platform),
     #[cfg(feature = "gitoxide-core-tools-corpus")]
     Corpus(corpus::Platform),
+    MergeBase(merge_base::Command),
+    Merge(merge::Platform),
+    Diff(diff::Platform),
+    Worktree(worktree::Platform),
     /// Subcommands that need no git repository to run.
     #[clap(subcommand)]
     Free(free::Subcommands),
@@ -267,6 +276,32 @@ pub mod status {
     }
 }
 
+pub mod merge_base {
+    #[derive(Debug, clap::Parser)]
+    #[command(about = "A command for calculating all merge-bases")]
+    pub struct Command {
+        /// A revspec for the first commit.
+        pub first: String,
+        /// Revspecs for the other commits to compute the merge-base with.
+        pub others: Vec<String>,
+    }
+}
+
+pub mod worktree {
+    #[derive(Debug, clap::Parser)]
+    #[command(about = "Commands for handling worktrees")]
+    pub struct Platform {
+        #[clap(subcommand)]
+        pub cmd: SubCommands,
+    }
+
+    #[derive(Debug, clap::Subcommand)]
+    pub enum SubCommands {
+        /// List all worktrees, along with some accompanying information
+        List,
+    }
+}
+
 #[cfg(feature = "gitoxide-core-tools-corpus")]
 pub mod corpus {
     use std::path::PathBuf;
@@ -309,6 +344,71 @@ pub mod corpus {
     }
 }
 
+pub mod merge {
+    use gix::bstr::BString;
+
+    #[derive(Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, clap::ValueEnum)]
+    pub enum ResolveWith {
+        /// Use ours then theirs in case of conflict.
+        Union,
+        /// Use only ours in case of conflict.
+        Ours,
+        /// Use only theirs in case of conflict.
+        Theirs,
+    }
+
+    #[derive(Debug, clap::Parser)]
+    #[command(about = "perform merges of various kinds")]
+    pub struct Platform {
+        #[clap(subcommand)]
+        pub cmd: SubCommands,
+    }
+
+    #[derive(Debug, clap::Subcommand)]
+    pub enum SubCommands {
+        /// Merge a file by specifying ours, base and theirs.
+        File {
+            /// Decide how to resolve conflicts. If unset, write conflict markers and fail.
+            #[clap(long, short = 'c')]
+            resolve_with: Option<ResolveWith>,
+
+            /// A path or revspec to our file.
+            #[clap(value_name = "OURS", value_parser = crate::shared::AsBString)]
+            ours: BString,
+            /// A path or revspec to the base for both ours and theirs.
+            #[clap(value_name = "BASE", value_parser = crate::shared::AsBString)]
+            base: BString,
+            /// A path or revspec to their file.
+            #[clap(value_name = "OURS", value_parser = crate::shared::AsBString)]
+            theirs: BString,
+        },
+    }
+}
+
+pub mod diff {
+    use gix::bstr::BString;
+
+    /// Print all changes between two objects
+    #[derive(Debug, clap::Parser)]
+    pub struct Platform {
+        #[clap(subcommand)]
+        pub cmd: SubCommands,
+    }
+
+    #[derive(Debug, clap::Subcommand)]
+    pub enum SubCommands {
+        /// Diff two trees.
+        Tree {
+            /// A rev-spec representing the 'before' or old tree.
+            #[clap(value_parser = crate::shared::AsBString)]
+            old_treeish: BString,
+            /// A rev-spec representing the 'after' or new tree.
+            #[clap(value_parser = crate::shared::AsBString)]
+            new_treeish: BString,
+        },
+    }
+}
+
 pub mod config {
     use gix::bstr::BString;
 
@@ -567,7 +667,7 @@ pub mod clean {
         /// Remove whole directories.
         #[arg(long, short = 'd')]
         pub directories: bool,
-        /// Remove nested repositories.
+        /// Remove nested repositories, even outside ignored directories.
         #[arg(long, short = 'r')]
         pub repositories: bool,
         /// Pathspec patterns are used to match the result of the dirwalk, not the dirwalk itself.
@@ -577,6 +677,9 @@ pub mod clean {
         #[arg(long, short = 'm')]
         pub pathspec_matches_result: bool,
         /// Enter ignored directories to skip repositories contained within.
+        ///
+        /// This identifies and avoids deleting separate repositories that are nested inside
+        /// ignored directories eligible for removal.
         #[arg(long)]
         pub skip_hidden_repositories: Option<FindRepository>,
         /// What kind of repositories to find inside of untracked directories.
@@ -704,17 +807,16 @@ pub mod credential {
 }
 
 ///
-#[allow(clippy::empty_docs)]
 pub mod commitgraph {
     #[derive(Debug, clap::Subcommand)]
     pub enum Subcommands {
-        /// Verify the integrity of a commit graph
+        /// Verify the integrity of a commit graph file
         Verify {
-            /// output statistical information about the pack
+            /// output statistical information about the graph.
             #[clap(long, short = 's')]
             statistics: bool,
         },
-        /// List all entries in the commit-graph as reachable by starting from `HEAD`.
+        /// List all entries in the commit-graph file as reachable by starting from `HEAD`.
         List {
             /// The rev-spec to list reachable commits from.
             #[clap(default_value = "@")]
@@ -936,5 +1038,4 @@ pub mod submodule {
 }
 
 ///
-#[allow(clippy::empty_docs)]
 pub mod free;
